@@ -11,22 +11,23 @@ OC.L10N.register(
     "SMTP Password" : "SMPT Lozinka",
     "Save" : "Spremi",
     "Cancel" : "Otkaži",
+    "Delete" : "Obriši",
+    "Search" : "Search",
     "Send" : "Pošalji",
+    "Choose" : "Izaberite",
     "Favorite" : "Favorit",
     "Select" : "Select",
     "Edit tags" : "Izmjeni oznake",
+    "Description" : "Opis",
     "Create" : "Ustvari",
     "Comment" : "Komentar",
     "Accept" : "Prihvati",
     "Decline" : "Odbij",
-    "Choose" : "Izaberite",
     "Other" : "Ostali",
     "Move" : "Move",
     "Quota" : "Kvota",
-    "Delete" : "Obriši",
     "Add" : "Dodaj",
     "Close" : "Zatvori",
-    "Search" : "Search",
     "Date" : "Date",
     "Disabled" : "Onemogućeno",
     "Enabled" : "Aktivirano",
@@ -34,7 +35,6 @@ OC.L10N.register(
     "User" : "User",
     "Port" : "Priključak",
     "Valid until" : "Validno do",
-    "Keyboard shortcuts" : "Tipkovni prečaci",
     "All" : "Sve",
     "Favorites" : "Favoriti"
 },
