@@ -6,6 +6,7 @@ declare(strict_types=1);
  * @copyright 2019 Christoph Wurst <christoph@winzerhof-wurst.at>
  *
  * @author 2019 Christoph Wurst <christoph@winzerhof-wurst.at>
+ * @author 2024 Richard Steinmetz <richard@steinmetz.cloud>
  *
  * @license GNU AGPL version 3 or any later version
  *
@@ -29,6 +30,7 @@ use OCA\Mail\AppInfo\Application;
 use OCA\Mail\Exception\ValidationException;
 use OCA\Mail\Http\JsonResponse as HttpJsonResponse;
 use OCA\Mail\Service\AntiSpamService;
+use OCA\Mail\Service\Classification\ClassificationSettingsService;
 use OCA\Mail\Service\Provisioning\Manager as ProvisioningManager;
 use OCP\AppFramework\Controller;
 use OCP\AppFramework\Http\JSONResponse;
@@ -42,19 +44,21 @@ class SettingsController extends Controller {
 	private ProvisioningManager $provisioningManager;
 	private AntiSpamService $antiSpamService;
 	private ContainerInterface $container;
-
 	private IConfig $config;
+	private ClassificationSettingsService $classificationSettingsService;
 
 	public function __construct(IRequest $request,
 		ProvisioningManager $provisioningManager,
 		AntiSpamService $antiSpamService,
 		IConfig $config,
-		ContainerInterface $container) {
+		ContainerInterface $container,
+		ClassificationSettingsService $classificationSettingsService) {
 		parent::__construct(Application::APP_ID, $request);
 		$this->provisioningManager = $provisioningManager;
 		$this->antiSpamService = $antiSpamService;
 		$this->config = $config;
 		$this->container = $container;
+		$this->classificationSettingsService = $classificationSettingsService;
 	}
 
 	public function index(): JSONResponse {
@@ -130,4 +134,9 @@ class SettingsController extends Controller {
 		return new JSONResponse([]);
 	}
 
+	public function setImportanceClassificationEnabledByDefault(bool $enabledByDefault): JSONResponse {
+		$this->classificationSettingsService->setClassificationEnabledByDefault($enabledByDefault);
+		return new JSONResponse([]);
+	}
+
 }
