@@ -38,7 +38,7 @@ class Folder {
 	/** @var string */
 	private $delimiter;
 
-	/** @var array */
+	/** @var null|array */
 	private $status;
 
 	/** @var string[] */
@@ -46,12 +46,16 @@ class Folder {
 
 	private ?string $myAcls;
 
-	public function __construct(int $accountId, Horde_Imap_Client_Mailbox $mailbox, array $attributes, ?string $delimiter) {
+	public function __construct(int $accountId,
+		Horde_Imap_Client_Mailbox $mailbox,
+		array $attributes,
+		?string $delimiter,
+		?array $status) {
 		$this->accountId = $accountId;
 		$this->mailbox = $mailbox;
 		$this->attributes = $attributes;
 		$this->delimiter = $delimiter;
-		$this->status = [];
+		$this->status = $status;
 		$this->specialUse = [];
 		$this->myAcls = null;
 	}
@@ -72,9 +76,9 @@ class Folder {
 	}
 
 	/**
-	 * @return array
+	 * @return null|array
 	 */
-	public function getStatus(): array {
+	public function getStatus(): ?array {
 		return $this->status;
 	}
 
